/**
 *******************************************************************************
 * @file    tmpm3Vx_dnf.h
 * @brief   This file provides all the functions prototypes for DNF driver.
 * @version V2.0.2.1
 * @date    2015/06/26
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

/* Define to prevent recursive inclusion ------------------------------------*/
#ifndef __TMPM3Vx_DNF_H
#define __TMPM3Vx_DNF_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes -----------------------------------------------------------------*/
#ifdef TMPM3V6
#include "TMPM3V6.h"
#elif TMPM3V4
#include "TMPM3V4.h"
#endif
#include "tx03_common.h"

/** @addtogroup TX03_Periph_Driver
  * @{
  */

/** @addtogroup DNF
  * @{
  */

/** @defgroup DNF_Exported_Types
  * @{
  */

/** @} */
/* End of group DNF_Exported_Types */

/** @defgroup DNF_Exported_Constants
  * @{
  */

#define DNF_FILTER_CLK_STOP           ((uint32_t)0x00000000)
#define DNF_FILTER_CLK_FSYS_2         ((uint32_t)0x00000001)
#define DNF_FILTER_CLK_FSYS_4         ((uint32_t)0x00000002)
#define DNF_FILTER_CLK_FSYS_8         ((uint32_t)0x00000003)
#define DNF_FILTER_CLK_FSYS_16        ((uint32_t)0x00000004)
#define DNF_FILTER_CLK_FSYS_32        ((uint32_t)0x00000005)
#define DNF_FILTER_CLK_FSYS_64        ((uint32_t)0x00000006)
#define DNF_FILTER_CLK_FSYS_128       ((uint32_t)0x00000007)

#define IS_DNF_FILTER_CLK(param)      (((param) == DNF_FILTER_CLK_STOP) || \
                                       ((param) == DNF_FILTER_CLK_FSYS_2) || \
                                       ((param) == DNF_FILTER_CLK_FSYS_4) || \
                                       ((param) == DNF_FILTER_CLK_FSYS_8) || \
                                       ((param) == DNF_FILTER_CLK_FSYS_16) || \
                                       ((param) == DNF_FILTER_CLK_FSYS_32) || \
                                       ((param) == DNF_FILTER_CLK_FSYS_64) || \
                                       ((param) == DNF_FILTER_CLK_FSYS_128))

/** @} */
/* End of DNF_Exported_Constants */

/** @defgroup DNF_Exported_FunctionPrototypes
  * @{
  */

    void DNF_SetFilterClk(uint32_t FilterClk);
    uint32_t DNF_GetFilterClk(void);
    void DNF_SetInt0Filter(volatile FunctionalState NewState);
    FunctionalState DNF_GetInt0FilterState(void);
    void DNF_SetInt1Filter(volatile FunctionalState NewState);
    FunctionalState DNF_GetInt1FilterState(void);
    void DNF_SetInt2Filter(volatile FunctionalState NewState);
    FunctionalState DNF_GetInt2FilterState(void);
    void DNF_SetInt3Filter(volatile FunctionalState NewState);
    FunctionalState DNF_GetInt3FilterState(void);
    void DNF_SetInt4Filter(volatile FunctionalState NewState);
    FunctionalState DNF_GetInt4FilterState(void);
    void DNF_SetInt5Filter(volatile FunctionalState NewState);
    FunctionalState DNF_GetInt5FilterState(void);
#ifdef TMPM3V6
    void DNF_SetInt6Filter(volatile FunctionalState NewState);
    FunctionalState DNF_GetInt6FilterState(void);
    void DNF_SetInt7Filter(volatile FunctionalState NewState);
    FunctionalState DNF_GetInt7FilterState(void);
#endif
    void DNF_SetInt8Filter(volatile FunctionalState NewState);
    FunctionalState DNF_GetInt8FilterState(void);
#ifdef TMPM3V6
    void DNF_SetInt9Filter(volatile FunctionalState NewState);
    FunctionalState DNF_GetInt9FilterState(void);
    void DNF_SetIntAFilter(volatile FunctionalState NewState);
    FunctionalState DNF_GetIntAFilterState(void);
    void DNF_SetIntBFilter(volatile FunctionalState NewState);
    FunctionalState DNF_GetIntBFilterState(void);
    void DNF_SetIntCFilter(volatile FunctionalState NewState);
    FunctionalState DNF_GetIntCFilterState(void);
    void DNF_SetIntDFilter(volatile FunctionalState NewState);
    FunctionalState DNF_GetIntDFilterState(void);
    void DNF_SetIntEFilter(volatile FunctionalState NewState);
    FunctionalState DNF_GetIntEFilterState(void);
#endif
    void DNF_SetIntFFilter(volatile FunctionalState NewState);
    FunctionalState DNF_GetIntFFilterState(void);

/** @} */
/* End of DNF_Exported_FunctionPrototypes */

/** @} */
/* End of group DNF */

/** @} */
/* End of group TX03_Periph_Driver */

#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __TMPM3Vx_DNF_H */
