/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of CG_ModeSwitch demo for the TOSHIBA
 *          'TMPM3Vx' Device Series 
 * @version V0.200
 * @date    2019/05/10
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */
/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "common_uart.h"
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define NORMAL_MODE             ((uint8_t)0x00)
#define STOP_MODE               ((uint8_t)0x01)
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Global variables ----------------------------------------------------------*/
uint8_t gCurrentMode = NORMAL_MODE;
/* external variables --------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
void Mode_Judgement(void);
void System_Init(void);

/* Main function */
int main(void)
{
    System_Init();

    /* Disable interrupts */
    __disable_irq();
    CG_ClearINTReq(CG_INT_SRC_0);
    /* Set external interrupt to wake up system */
    CG_SetSTBYReleaseINTSrc(CG_INT_SRC_0, CG_INT_ACTIVE_STATE_RISING, ENABLE);
    NVIC_ClearPendingIRQ(INT0_IRQn);
    NVIC_EnableIRQ(INT0_IRQn);
    __enable_irq();

    /* Initialize Variables */
    gCurrentMode = NORMAL_MODE;

    while (1) {
        Mode_Judgement();  /* Push SW4 to change Mode */

        switch (gCurrentMode) {
        case NORMAL_MODE:
            LED_On(LED_ALL);
            common_uart_disp("NORMAL MODE\r\n");
            break;
        case STOP_MODE:
            LED_Off(LED_ALL);
            common_uart_disp("STOP MODE\r\n");

			UART_SWReset(UART_RETARGET);
			UART_Disable(UART_RETARGET);
        	/* Set PE0 as PE0 */
        	GPIO_SetOutputEnableReg(GPIO_PE, GPIO_BIT_0, DISABLE);
        	GPIO_DisableFuncReg(GPIO_PE, GPIO_FUNC_REG_1, GPIO_BIT_0);
        	/* Set PE1 as PE1 */
        	GPIO_SetInputEnableReg(GPIO_PE, GPIO_BIT_1, DISABLE);
        	GPIO_DisableFuncReg(GPIO_PE, GPIO_FUNC_REG_1, GPIO_BIT_1);

            /* Switch from Normal mode to Stop mode */
            CG_NormalToStop();

            /* MCU is entered to STOP mode
               Wait for INT0 to wake system */
            
            System_Init();
            gCurrentMode = NORMAL_MODE;
            break;
        default:
            gCurrentMode = NORMAL_MODE;
            break;
        }
    }

}

/**
  * @brief  Judge whether go to STOP_MODE
  * @param  None.
  * @retval None.
  */
void Mode_Judgement(void)
{
    if ((SW_Get(SW4) == 1U) && (gCurrentMode == NORMAL_MODE)) {
        gCurrentMode = STOP_MODE;
    } else {
        /* Do nothing */
    }
}

/**
  * @brief  Initialize system
  * @param  None.
  * @retval None.
  */
void System_Init(void)
{
    /* Initialize system */
    CG_SetSystem();

    /* Configure GPIO for wakeup interrupt INT0 */
    GPIO_SetInput(GPIO_PH, GPIO_BIT_0);    /* Set PH0 to input */
    GPIO_EnableFuncReg(GPIO_PH, GPIO_FUNC_REG_1, GPIO_BIT_0);    /* Set PH0 for INT0 */
    GPIO_SetPullDown(GPIO_PH, GPIO_BIT_0, ENABLE);

    /* Configure GPIO for LED */
    LED_Init();

    /* Configure GPIO for SW */
    SW_Init();

    /* Configure GPIO for UART */
    hardware_init(UART_RETARGET);
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif

/*********************************** END OF FILE ******************************/
