/**
 ******************************************************************************
 * @file     led.c
 * @brief    LED driver for the TOSHIBA 'TMPM3Vx' Device Series
 * @version  V0.200
 * @date     2019/05/10
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 ******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "led.h"

/**
  * @brief  Initialize LED ports.
  *   LED0~3 connect with PG4~7/PA0~3.
  * @param  None
  * @retval None
  */
void LED_Init(void)
{
#ifdef TMPM3V6
    /* Set PG4 ~ PG7 as output and turn off LED0 ~ LED3 */
    GPIO_SetPullDown(GPIO_PG, GPIO_BIT_4 | GPIO_BIT_5 | GPIO_BIT_6 | GPIO_BIT_7, ENABLE);
    GPIO_SetOutput(GPIO_PG, GPIO_BIT_4 | GPIO_BIT_5 | GPIO_BIT_6 | GPIO_BIT_7);
#elif TMPM3V4
    /* Set PA0 ~ PA3 as output and turn off LED0 ~ LED3 */
    GPIO_SetPullDown(GPIO_PA, GPIO_BIT_0 | GPIO_BIT_1 | GPIO_BIT_2 | GPIO_BIT_3, ENABLE);
    GPIO_SetOutput(GPIO_PA, GPIO_BIT_0 | GPIO_BIT_1 | GPIO_BIT_2 | GPIO_BIT_3);
#endif
}

/**
  * @brief  Turn on input LED.
  * @param  led: LED number
  *   This parameter can be one of the following values:
  *   LED0, LED1, LED2, LED3 or LED_ALL.
  * @retval None
  */
void LED_On(uint8_t led)
{
#ifdef TMPM3V6
    uint8_t tmp;
    tmp = GPIO_ReadData(GPIO_PG);
    tmp |= led;
    GPIO_WriteData(GPIO_PG, tmp);
#elif TMPM3V4
    uint8_t tmp;
    tmp = GPIO_ReadData(GPIO_PA);
    tmp |= led;
    GPIO_WriteData(GPIO_PA, tmp);
#endif
}

/**
  * @brief  Turn off input LED.
  * @param  led: LED number
  *   This parameter can be one of the following values:
  *   LED0, LED1, LED2, LED3 or LED_ALL.
  * @retval None
  */
void LED_Off(uint8_t led)
{
#ifdef TMPM3V6
    uint8_t tmp;
    tmp = GPIO_ReadData(GPIO_PG);
    tmp &= (uint8_t) (~led);
    GPIO_WriteData(GPIO_PG, tmp);
#elif TMPM3V4
    uint8_t tmp;
    tmp = GPIO_ReadData(GPIO_PA);
    tmp &= (uint8_t) (~led);
    GPIO_WriteData(GPIO_PA, tmp);
#endif
}
