/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of VLTD (Voltage Detection Circuit) demo
 *          for the TOSHIBA 'TMPM3Vx' Device Series
 * @version V0.200
 * @date    2019/05/10
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

#include "tmpm3Vx_cg.h"
#include "tmpm3Vx_gpio.h"
#include "tmpm3Vx_vltd.h"
#include "tmpm3Vx_wdt.h"

int main(void)
{
    WDT_Disable();                        /* Disable WDT explicitly */
    GPIO_SetOutput(GPIO_PH, GPIO_BIT_0);  /* Set PH0 as output port */

    if (CG_GetResetFlag().Bit.PowerOn == 0U) {
        VLTD_Enable();                    /* Enable VLTD function */
        GPIO_WriteData(GPIO_PH, 0x00U);    /* Set PH0 to LOW */
    } else {
        VLTD_Disable();                   /* Disable VLTD function */
        GPIO_WriteData(GPIO_PH, 0x01U);    /* Set PH0 to HIGH */
    }

    while (1U) {
        /* Do nothing */
    }
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1U) {
        __NOP();
    }
}
#endif
